Enum RescanConfidence

pub enum RescanConfidence {
    High,
    Medium,
    Low,
    Exact,
}
A confidence enum to auxiliate rescan timestamp values.

Tells how much confidence you need for this rescan request. That is, the how conservative you want floresta to be when determining which block to start the rescan. will make the rescan to start in a block that have an lower timestamp than the given in order to be more certain about finding addresses and relevant transactions, a lower confidence will make the rescan to be closer to the given value.

This input is necessary to cover network variancy specially in testnet, for mainnet you can safely use low or medium confidences depending on how much sure you are about the given timestamp covering the addresses you need.

Variants



High

high: 99% confidence interval. Meaning 46 minutes in seconds.



Medium

medium (default): 95% confidence interval. Meaning 30 minutes in seconds.



Low

low: 90% confidence interval. Meaning 23 minutes in seconds.



Exact

exact: Removes any lookback addition. Meaning 0 in seconds.