pub struct MemInfoLocked {
pub used: u64,
pub free: u64,
pub total: u64,
pub locked: u64,
pub chunks_used: u64,
pub chunks_free: u64,
}Fields
used: u64Memory currently in use, in bytes
free: u64Memory currently free, in bytes
total: u64Total memory allocated, in bytes
locked: u64Total memory locked, in bytes
If total is less than total, then some pages may be on swap or not philysically allocated yet
chunks_used: u64How many chunks are currently in use
chunks_free: u64How many chunks are currently free